@@ -57,7 +57,6 @@
 #include "ctkpowersavings.h"
 #include "ctk3dvisionpro.h"
 
-#include "ctkdisplaydevice-tv.h"
 #include "ctkdisplaydevice.h"
 
 #include "ctkdisplayconfig.h"
@@ -1465,27 +1464,16 @@ static void add_display_devices(CtkWindow *ctk_window, GtkTreeIter *iter,
         XFree(logName);
         XFree(typeIdName);
 
-        /* Create the appropriate page for the display */
-        if (strcmp(typeBaseName, "TV") == 0) {
-            widget = ctk_display_device_tv_new
-                (display_handle, ctk_window->ctk_config, ctk_event, title);
-            help = ctk_display_device_tv_create_help
-                (tag_table, CTK_DISPLAY_DEVICE_TV(widget));
-        } else if ((strcmp(typeBaseName, "DFP") == 0) ||
-                   (strcmp(typeBaseName, "CRT") == 0)) {
-            widget = ctk_display_device_new(display_handle,
-                                            ctk_window->ctk_config, ctk_event,
-                                            ctk_event_gpu,
-                                            title, typeBaseName, p);
-            help = ctk_display_device_create_help(tag_table,
-                                                  CTK_DISPLAY_DEVICE(widget));
-        } else {
-            widget = NULL;
-        }
-
-        if (!widget) {
+        /* Create the page for the display */
+        widget = ctk_display_device_new(display_handle,
+                                        ctk_window->ctk_config, ctk_event,
+                                        ctk_event_gpu,
+                                        title, typeBaseName, p);
+        if (widget == NULL) {
             NvCtrlAttributeClose(display_handle);
         } else {
+            help = ctk_display_device_create_help(tag_table,
+                                                  CTK_DISPLAY_DEVICE(widget));
             add_page(widget, help, ctk_window, iter,
                      &(data->display_iters[data->num_displays]), title,
                      NULL, NULL, NULL);
